[webbeans-commits] Webbeans SVN: r1258 - in tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit: implementation/commonAnnotations and 9 other directories.

webbeans-commits at lists.jboss.org webbeans-commits at lists.jboss.org
Wed Jan 28 03:29:38 EST 2009


Author: shane.bryzak at jboss.com
Date: 2009-01-28 03:29:38 -0500 (Wed, 28 Jan 2009)
New Revision: 1258

Modified:
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/event/EventTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/commonAnnotations/ResourceInjectionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/decorator/DecoratorDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/deployment/BeanDeploymentTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanDeclarationTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanLifecycleTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanRemoveMethodTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/NewEnterpriseBeanTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/initializer/InitializerMethodTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/interceptor/InterceptorDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/jms/JmsDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldLifecycleTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/DisposalMethodDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodLifecycleTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/NewSimpleBeanTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanDefinitionTest.java
   tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanLifecycleTest.java
Log:
updated event and implementation tests to latest spec

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/event/EventTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/event/EventTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/event/EventTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -17,7 +17,6 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
 /**
@@ -26,8 +25,8 @@
  * @author Nicklas Karlsson
  * @author David Allen
  * 
+ * Spec version: PRD2
  */
- at SpecVersion("20081206")
 public class EventTest extends AbstractTest
 {
 
@@ -81,14 +80,14 @@
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.1")
+   @SpecAssertion(section = "7.1")
    public void testEventTypeIncludesAllSuperclassesAndInterfacesOfEventObject()
    {
       assert false;
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.2")
+   @SpecAssertion(section = "7.2")
    public void testManagerFireEvent()
    {
       // First a simple event with no bindings is fired
@@ -104,7 +103,7 @@
     * variables or wildcards, an IllegalArgumentException is thrown
     */
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = { "8.1", "8.2" })
+   @SpecAssertion(section = { "7.1", "7.2" })
    public void testManagerFireEventWithEventTypeParametersFails()
    {
       ATemplatedEventType<String> anEvent = new ATemplatedEventType<String>();
@@ -116,7 +115,7 @@
     * variables or wildcards, an IllegalArgumentException is thrown
     */
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = { "8.1", "8.2" })
+   @SpecAssertion(section = { "7.1", "7.2" })
    public void testManagerFireEventWithEventTypeWildcardsFails()
    {
       // Although the above test is really the same as with a wildcard, we will
@@ -127,7 +126,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = { "8.1", "8.2" })
+   @SpecAssertion(section = { "7.1", "7.2" })
    public void testManagerFireEventWithNonBindingAnnotationsFails()
    {
       // The specs are not exactly clear on what is supposed to happen here,
@@ -139,7 +138,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.3")
+   @SpecAssertion(section = "7.3")
    public void testManagerAddObserver()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -187,7 +186,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.3")
+   @SpecAssertion(section = "7.3")
    public void testManagerRemoveObserver()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -221,7 +220,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DuplicateBindingTypeException.class })
-   @SpecAssertion(section = "8.3")
+   @SpecAssertion(section = "7.3")
    public void testMultipleInstancesOfSameBindingTypeWhenAddingObserverFails()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -229,7 +228,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = "8.3")
+   @SpecAssertion(section = "7.3")
    public void testNonBindingTypePassedToAddObserverFails()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -237,7 +236,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DuplicateBindingTypeException.class })
-   @SpecAssertion(section = "8.3")
+   @SpecAssertion(section = "7.3")
    public void testMultipleInstancesOfSameBindingTypeWhenRemovingObserverFails()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -246,7 +245,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = "8.3")
+   @SpecAssertion(section = "7.3")
    public void testNonBindingTypePassedToRemoveObserverFails()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -255,7 +254,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = { "8.1", "8.4" })
+   @SpecAssertion(section = { "7.1", "7.4" })
    public void testConsumerNotifiedWhenEventTypeAndAllBindingsMatch()
    {
       AnObserver observer1 = new AnObserver();
@@ -272,7 +271,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.4")
+   @SpecAssertion(section = "7.4")
    public void testObserverThrowsExceptionAbortsNotifications()
    {
       AnObserverWithException observer = new AnObserverWithException();
@@ -299,7 +298,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.5")
+   @SpecAssertion(section = "7.5")
    public void testMultipleObserverMethodsOK()
    {
       // This bean has a couple observer methods
@@ -316,7 +315,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = { "8.5.1", "8.5.2" })
+   @SpecAssertion(section = { "7.5.1", "7.5.2" })
    public void testObserverMethodMustHaveOnlyOneEventParameter()
    {
       deployBeans(YorkshireTerrier_Broken.class);
@@ -326,7 +325,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.5.1")
+   @SpecAssertion(section = "7.5.1")
    public void testObserverMethodCannotObserveParameterizedEvents()
    {
       deployBeans(BostonTerrier.class);
@@ -335,7 +334,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.5.1")
+   @SpecAssertion(section = "7.5.1")
    public void testObserverMethodWithoutBindingTypesObservesEventsWithoutBindingTypes()
    {
       // This observer has no binding types specified
@@ -349,7 +348,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.5.2")
+   @SpecAssertion(section = "7.5.2")
    public void testObserverMethodAnnotatedProducesFails()
    {
       deployBeans(BorderTerrier.class);
@@ -358,7 +357,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.5.2")
+   @SpecAssertion(section = "7.5.2")
    public void testObserverMethodAnnotatedInitializerFails()
    {
       deployBeans(AustralianTerrier.class);
@@ -367,7 +366,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.5.2")
+   @SpecAssertion(section = "7.5.2")
    public void testObserverMethodWithDisposesParamFails()
    {
       deployBeans(FoxTerrier.class);
@@ -376,7 +375,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.5.2")
+   @SpecAssertion(section = "7.5.2")
    public void testObserverMethodMayHaveMultipleBindingTypes()
    {
       deployBeans(BullTerrier.class);
@@ -390,21 +389,21 @@
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.3")
+   @SpecAssertion(section = "7.5.3")
    public void testXMLDefinedObserverMethodIgnoresBindingAnnotations()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.3")
+   @SpecAssertion(section = "7.5.3")
    public void testXMLDefinedObserverNotFindingImplementationMethodFails()
    {
       assert false;
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.5.4")
+   @SpecAssertion(section = "7.5.4")
    public void testObserverMethodReceivesInjectionsOnNonObservesParameters()
    {
       deployBeans(BananaSpider.class);
@@ -417,7 +416,7 @@
     * is created by some other separate action.
     */
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.5.5")
+   @SpecAssertion(section = "7.5.5")
    public void testConditionalObserver()
    {
       RecluseSpider.notified = false;
@@ -444,49 +443,49 @@
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.1")
+   @SpecAssertion(section = "7.1")
    public void testTransactionalObserverCanOnlyObserveSinglePhase()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.6")
+   @SpecAssertion(section = "7.5.6")
    public void testTransactionalObserverNotifiedImmediatelyWhenNoTransactionInProgress()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.6")
+   @SpecAssertion(section = "7.5.6")
    public void testAfterTransactionCompletionObserver()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.6")
+   @SpecAssertion(section = "7.5.6")
    public void testAfterTransactionSuccessObserver()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.6")
+   @SpecAssertion(section = "7.5.6")
    public void testAfterTransactionFailureObserver()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.5.6")
+   @SpecAssertion(section = "7.5.6")
    public void testBeforeTransactionCompletionObserver()
    {
       assert false;
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.5.7")
+   @SpecAssertion(section = "7.5.8")
    public void testObserverMethodRegistration()
    {
       // This bean has two observer methods, one static and one non-static
@@ -500,7 +499,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { TeaCupPomeranian.OversizedException.class })
-   @SpecAssertion(section = "8.5.7")
+   @SpecAssertion(section = "7.5.8")
    public void testNonTransactionalObserverThrownNonCheckedExceptionIsRethrown()
    {
       deployBeans(TeaCupPomeranian.class);
@@ -510,7 +509,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { ObserverException.class })
-   @SpecAssertion(section = "8.5.7")
+   @SpecAssertion(section = "7.5.8")
    public void testNonTransactionalObserverThrownCheckedExceptionIsWrappedAndRethrown()
    {
       deployBeans(TeaCupPomeranian.class);
@@ -520,7 +519,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DuplicateBindingTypeException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testDuplicateBindingsToFireFails()
    {
       deployBeans(SweeWaxbill_Broken.class);
@@ -537,7 +536,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DuplicateBindingTypeException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testDuplicateBindingsToObservesFails()
    {
       deployBeans(SweeWaxbill_Broken.class);
@@ -554,7 +553,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testNonBindingTypePassedToFireFails()
    {
       deployBeans(OwlFinch_Broken.class);
@@ -571,7 +570,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testNonBindingTypePassedToObservesFails()
    {
       deployBeans(OwlFinch_Broken.class);
@@ -588,7 +587,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFiresAnnotationOnEventTypes()
    {
       deployBeans(BlueFacedParrotFinch.class);
@@ -651,7 +650,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFiresAnnotationOnNonEventTypeInjectionPointFails()
    {
       deployBeans(CommonWaxbill_Broken.class);
@@ -668,7 +667,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFiresAnnotationOnInjectionPointWithoutTypeParameterFails()
    {
       deployBeans(BlackRumpedWaxbill_Broken.class);
@@ -685,7 +684,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFiresAnnotationOnInjectionPointWithWildcardedTypeParameterFails()
    {
       deployBeans(GoldbreastWaxbill_Broken.class);
@@ -702,7 +701,7 @@
    }
 
    @Test(groups = { "events" }, expectedExceptions = { DefinitionException.class })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFiresAnnotationOnInjectionPointWithTypeVariabledTypeParameterFails()
    {
       deployBeans(JavaSparrow_Broken.class);
@@ -719,7 +718,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testImplicitEventBeanMatchesAPITypeOfInectionPoint()
    {
       deployBeans(BlueFacedParrotFinch.class);
@@ -740,7 +739,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testImplicitEventBeanMatchesBindingAnnotationsOfInjectionPoint()
    {
       deployBeans(OrangeCheekedWaxbill.class);
@@ -761,7 +760,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testImplicitEventBeanHasStandardDeploymentType()
    {
       deployBeans(BlueFacedParrotFinch.class);
@@ -784,7 +783,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testImplicitEventBeanHasDependentScope()
    {
       deployBeans(BlueFacedParrotFinch.class);
@@ -807,70 +806,70 @@
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFireMethodCallsManagerFireWithEventObject()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFireMethodCallsManagerFireWithBindingAnnotationsExceptObservable()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testFireMethodCallsManagerFireWithAllBindingAnnotationInstances()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testObserveMethodCallsManagerAddObserverWithObserverObject()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testObserveMethodCallsManagerAddObserverWithAllBindingAnnotationsExceptObservable()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.6")
+   @SpecAssertion(section = "7.6")
    public void testObserveMethodCallsManagerAddObserverWithAllBindingAnnotationInstance()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testEventObjectContainsTypeVariablesWhenResolvingFails()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testEventObjectContainsWildcardsWhenResolvingFails()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testDuplicateBindingTypesWhenResolvingFails()
    {
       assert false;
    }
 
    @Test(groups = { "events" }, expectedExceptions = { IllegalArgumentException.class })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testNonBindingTypeAnnotationWhenResolvingFails()
    {
       AnObserver observer = new AnObserver();
@@ -882,7 +881,7 @@
    }
 
    @Test(groups = { "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testResolvingChecksEventType()
    {
       Observer<AnEventType> observer = new AnObserver();
@@ -894,7 +893,7 @@
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testResolvingChecksTypeParameters()
    {
       AListObserver observer = new AListObserver();
@@ -906,21 +905,21 @@
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testResolvingChecksBindingTypes()
    {
       assert false;
    }
 
    @Test(groups = { "stub", "events" })
-   @SpecAssertion(section = "8.7")
+   @SpecAssertion(section = "7.7")
    public void testResolvingChecksBindingTypeMembers()
    {
       assert false;
    }
 
    @Test
-   @SpecAssertion(section = "4.2")
+   @SpecAssertion(section = "???")
    public void testNonStaticObserverMethodNotInherited()
    {
       deployBeans(LazyFarmer.class);
@@ -928,7 +927,7 @@
    }
 
    @Test
-   @SpecAssertion(section = "8.5.8")
+   @SpecAssertion(section = "7.5.8")
    public void testObserverCalledOnMostSpecializedInstance()
    {
       Shop.deliveryObservedBy = null;

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/commonAnnotations/ResourceInjectionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/commonAnnotations/ResourceInjectionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/commonAnnotations/ResourceInjectionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -4,6 +4,11 @@
 import org.jboss.webbeans.tck.impl.SpecAssertion;
 import org.testng.annotations.Test;
 
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class ResourceInjectionTest extends AbstractTest
 {
    

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/decorator/DecoratorDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/decorator/DecoratorDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/decorator/DecoratorDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -6,13 +6,13 @@
 public class DecoratorDefinitionTest
 {
    
-   @Test(groups="stub") @SpecAssertion(section="4.2")
+   @Test(groups="stub") @SpecAssertion(section="A.5")
    public void testDecoratorBindingInherited()
    {
       assert false;
    }
    
-   @Test(groups="stub") @SpecAssertion(section="4.2")
+   @Test(groups="stub") @SpecAssertion(section="A.5")
    public void testDecoratorBindingBlockedByIntermediateClass()
    {
       assert false;

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/deployment/BeanDeploymentTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/deployment/BeanDeploymentTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/deployment/BeanDeploymentTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -1,104 +1,107 @@
 package org.jboss.webbeans.tck.unit.implementation.deployment;
 
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081222")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class BeanDeploymentTest
 {
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.7")
    public void testOnlySpecializedSimpleBeanDeployed()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.7")
    public void testSpecializedSimpleBeanExtends()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.7")
    public void testSpecializedSimpleBeanHasSameBindingAnnotations()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.7")
    public void testSpecializedSimpleBeanHasSameName()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.7")
    public void testOnlySpecializedEnterpriseBeanDeployed()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.7")
    public void testSpecializedEnterpriseBeanExtends()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.7")
    public void testSpecializedEnterpriseBeanHasSameBindingAnnotations()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.7")
    public void testSpecializedEnterpriseBeanHasSameName()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.7")
    public void testSpecializedEnterpriseBeanAllLocalInterfaces()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.6")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.7")
    public void testSpecializedEnterpriseBeanSupportsBeanClassLocalView()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.3")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.4")
    public void testOnlySpecializedProducerMethodBeanDeployed()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.3")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.4")
    public void testSpecializedProducerMethodBeanDirectlyOverrides()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.3")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.4")
    public void testSpecializedProducerMethodBeanHasSameBindingAnnotations()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.3")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.4")
    public void testSpecializedProducerMethodBeanHasSameName()
    {
       // TODO Placeholder

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanDeclarationTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanDeclarationTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanDeclarationTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -4,7 +4,6 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
 /**
@@ -15,8 +14,9 @@
  * using annotations 3.3.4. Declaring an enterprise Web Bean using XML
  * 
  * @author Nicklas Karlsson
+ * 
+ * Spec version: PRD2
  */
- at SpecVersion("20081206")
 public class EnterpriseBeanDeclarationTest extends AbstractTest
 {
 
@@ -206,7 +206,7 @@
     * thus no special declaration is required.
     */
    @Test(groups = { "enterpriseBeans", "stub" })
-   @SpecAssertion(section = "3.3.1")
+   @SpecAssertion(section = "3.3.2")
    public void testAnnotatedEnterpriseBean()
    {
       // TODO: dupe?
@@ -218,7 +218,7 @@
     * by specifying the bean class in web-beans.xml.
     */
    @Test(groups = { "enterpriseBeans", "webbeansxml", "stub" })
-   @SpecAssertion(section = "3.3.1")
+   @SpecAssertion(section = "3.3.2")
    public void testAnnotatedEnterpriseBeanComplementedWithXML()
    {
       // TODO dupe?
@@ -230,7 +230,7 @@
     * ejb-jar.xml are also Web Beans.
     */
    @Test(groups = { "enterpriseBeans", "ejbjarxml", "stub" })
-   @SpecAssertion(section = "3.3.1")
+   @SpecAssertion(section = "3.3.2")
    public void testEJBJARDefinedEnterpriseBean()
    {
       // TODO dupe?
@@ -242,7 +242,7 @@
     * by specifying the bean class and EJB name in web-beans.xml
     */
    @Test(groups = { "enterpriseBeans", "ejbjarxml", "webbeansxml", "stub" })
-   @SpecAssertion(section = "3.3.1")
+   @SpecAssertion(section = "3.3.2")
    public void testEJBJARDefinedEnterpriseBeanComplementedWithXML()
    {
       // TODO dupe?
@@ -255,7 +255,7 @@
     * variables and their superinterfaces
     */
    @Test(groups = { "enterpriseBeans", "stub" })
-   @SpecAssertion(section = "3.3.2")
+   @SpecAssertion(section = "3.3.3")
    public void testAPITypesAreLocalInterfacesWithoutWildcardTypesOrTypeVariablesWithSuperInterfaces()
    {
       assert false;
@@ -267,7 +267,7 @@
     * superclasses
     */
    @Test(groups = { "enterpriseBeans", "stub" })
-   @SpecAssertion(section = "3.3.2")
+   @SpecAssertion(section = "3.3.3")
    public void testEnterpriseBeanWithLocalViewAndParameterizedTypeIncludesBeanClassAndSuperclassesInAPITypes()
    {
       assert false;
@@ -277,7 +277,7 @@
     * In addition, java.lang.Object is an API type of every enterprise Web Bean.
     */
    @Test(groups = "enterpriseBeans")
-   @SpecAssertion(section = "3.3.2")
+   @SpecAssertion(section = "3.3.3")
    public void testObjectIsInAPITypes()
    {
       assert createEnterpriseBean(Laika.class).getTypes().contains(Object.class);
@@ -287,7 +287,7 @@
     * Remote interfaces are not included in the set of API types.
     */
    @Test(groups = { "enterpriseBeans", "stub" })
-   @SpecAssertion(section = "3.3.2")
+   @SpecAssertion(section = "3.3.3")
    public void testRemoteInterfacesAreNotInAPITypes()
    {
       assert false;
@@ -324,7 +324,7 @@
     * to lower case.
     */
    @Test(groups = "enterpriseBeans")
-   @SpecAssertion(section = "3.3.7")
+   @SpecAssertion(section = "3.3.8")
    public void testDefaultName()
    {
       assert createEnterpriseBean(Pitbull.class).getName().equals("pitbull");

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanLifecycleTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanRemoveMethodTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanRemoveMethodTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -2,7 +2,6 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
 /**
@@ -13,8 +12,9 @@
  * 3.3.5.3. Remove method parameters
  * 
  * @author Nicklas Karlsson
+ * 
+ * Spec version: PRD2
  */
- at SpecVersion("20090116")
 public class EnterpriseBeanRemoveMethodTest extends AbstractTest
 {
 

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/NewEnterpriseBeanTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/NewEnterpriseBeanTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/NewEnterpriseBeanTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -13,12 +13,15 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.literals.NewLiteral;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081222")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class NewEnterpriseBeanTest extends AbstractTest
 {
    private Bean<WrappedEnterpriseBean> newEnterpriseBean;
@@ -42,7 +45,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanIsDependentScoped()
    {
       assert Dependent.class.equals(newEnterpriseBean.getScopeType());
@@ -57,7 +60,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanIsOfStandardDeploymentType()
    {
       assert Standard.class.equals(newEnterpriseBean.getDeploymentType());
@@ -72,7 +75,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanIsHasOnlyNewBinding()
    {
       assert newEnterpriseBean.getBindings().size() == 1;
@@ -88,7 +91,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoWebBeanName()
    {
       assert newEnterpriseBean.getName() == null;
@@ -103,7 +106,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "stub", "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoStereotypes()
    {
       assert false;
@@ -118,7 +121,7 @@
     * is an enterprise Web Bean.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanIsEnterpriseWebBeanIfParameterTypeIsEnterpriseWebBean()
    {
       assert false;
@@ -136,7 +139,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasSameInitializerMethodsAsWrappedBean()
    {
       assert false;
@@ -154,7 +157,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasSameInjectedFieldsAsWrappedBean()
    {
       assert false;
@@ -172,7 +175,7 @@
     * � has no decorators.
     */
    @Test(groups = {"new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoObservers()
    {
       assert false;
@@ -190,7 +193,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoProducerFields()
    {
       assert false;
@@ -208,7 +211,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoProducerMethods()
    {
       assert false;
@@ -226,7 +229,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoDisposalMethods()
    {
       assert false;
@@ -244,7 +247,7 @@
     * � has no decorators.
     */
    @Test(groups = { "stub", "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasSameInterceptorMethodsAsWrappedBean()
    {
       assert false;
@@ -262,7 +265,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewBeanHasNoDecorators()
    {
       Annotation[] bindingTypes = newEnterpriseBean.getBindings().toArray(new Annotation[0]);
@@ -278,7 +281,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationMayBeAppliedToField()
    {
       deployBeans(AnnotatedField.class, WrappedEnterpriseBean.class);
@@ -294,7 +297,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationMayBeAppliedToProducerMethodParameter()
    {
       deployBeans(AnnotatedProducerParameter.class, WrappedEnterpriseBean.class);
@@ -310,7 +313,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationMayBeAppliedToInitializerMethodParameter()
    {
       deployBeans(AnnotatedInitializerParameter.class, WrappedEnterpriseBean.class);
@@ -326,7 +329,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationMayBeAppliedToConstructorMethodParameter()
    {
       deployBeans(AnnotatedConstructorParameter.class, WrappedEnterpriseBean.class);
@@ -341,7 +344,7 @@
     * by the container at deployment time.
     */
    @Test(groups = { "new" }, expectedExceptions = DefinitionException.class)
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationCannotAppearInConjunctionWithOtherBindingType()
    {
       deployBeans(NewAndOtherBindingType_Broken.class);
@@ -355,7 +358,7 @@
     * by the container at deployment time.
     */
    @Test(groups = { "stub", "new" }, expectedExceptions = DefinitionException.class)
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationCannotBeAppliedToNonWebBeanImplementationClass()
    {
       assert false;
@@ -366,13 +369,13 @@
     * as a binding type
     */
    @Test(groups = { "stub", "new" }, expectedExceptions = DefinitionException.class)
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.3.6")
    public void testNewAnnotationCannotBeExplicitlyDeclared()
    {
       assert false;
    }
    
-   @Test @SpecAssertion(section="3.2.5")
+   @Test @SpecAssertion(section="3.2.6")
    public void testForEachEnterpriseBeanANewBeanExists()
    {
       deployBeans(Order.class, Lion.class);

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/initializer/InitializerMethodTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/initializer/InitializerMethodTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/initializer/InitializerMethodTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -5,57 +5,67 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.util.MockCreationalContext;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081206")
+/**
+ * 
+ * Spec version: PRD2
+ */
 public class InitializerMethodTest extends AbstractTest
 {
    
-   @Test(expectedExceptions=DefinitionException.class, groups="initializerMethod") @SpecAssertion(section="3.8")
+   @Test(expectedExceptions=DefinitionException.class, groups="initializerMethod") 
+   @SpecAssertion(section="3.8")
    public void testStaticInitializerMethodNotAllowed()
    {
       createSimpleBean(Dottrel.class);
    }
    
-   @Test(groups={"stub", "initializerMethod", "servlet"}) @SpecAssertion(section="3.8")
+   @Test(groups={"stub", "initializerMethod", "servlet"}) 
+   @SpecAssertion(section="3.9")
    public void testInitializerMethodCalledOnServlet()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "ejb3"}) @SpecAssertion(section="3.8")
+   @Test(groups={"stub", "initializerMethod", "ejb3"}) 
+   @SpecAssertion(section="3.9")
    public void testInitializerMethodCalledOnEJBSessionBean()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "ejb3"}) @SpecAssertion(section="3.8")
+   @Test(groups={"stub", "initializerMethod", "ejb3"}) 
+   @SpecAssertion(section="3.9")
    public void testInitializerMethodCalledOnEJBMDB()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "ejb3", "singletons"}) @SpecAssertion(section="3.8")
+   @Test(groups={"stub", "initializerMethod", "ejb3", "singletons"}) 
+   @SpecAssertion(section="3.9")
    public void testInitializerMethodCalledOnEJBSingleton()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "ejb3"}) @SpecAssertion(section="3.8")
+   @Test(groups={"stub", "initializerMethod", "ejb3"}) 
+   @SpecAssertion(section="3.9")
    public void testInitializerMethodNotABusinessMethod()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "interceptors"}) @SpecAssertion(section="3.8")
+   @Test(groups={"stub", "initializerMethod", "interceptors"}) 
+   @SpecAssertion(section="3.9")
    public void testMethodInterceptorNotCalledOnInitializerMethod()
    {
       assert false;
    }
    
-   @Test(groups={"initializerMethod"}) @SpecAssertion(section={"3.8", "5.3", "3.8.2", "3.8.3"})
+   @Test(groups={"initializerMethod"}) 
+   @SpecAssertion(section={"3.9", "5.3", "3.9.2", "3.9.3"})
    public void testMultipleInitializerMethodsAreCalled()
    {
       manager.addBean(createSimpleBean(Fox.class));
@@ -67,43 +77,50 @@
       assert chickenHutch.chicken != null;
    }
    
-   @Test(groups="initializerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section={"3.8.1", "3.4.2"})
+   @Test(groups="initializerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section={"3.9.1", "3.4.2"})
    public void testInitializerMethodAnnotatedProduces()
    {
       createSimpleBean(Pheasant.class);
    }
    
-   @Test(groups="initializerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.8.1")
+   @Test(groups="initializerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.9.1")
    public void testInitializerMethodHasParameterAnnotatedDisposes()
    {
       createSimpleBean(Capercaillie.class);
    }
    
-   @Test(groups="initializerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.8.1")
+   @Test(groups="initializerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.9.1")
    public void testInitializerMethodHasParameterAnnotatedObserves()
    {
       createSimpleBean(Grouse.class);
    }
    
-   @Test(groups={"stub", "initializerMethod", "webbeansxml"}) @SpecAssertion(section="3.8.2")
+   @Test(groups={"stub", "initializerMethod", "webbeansxml"}) 
+   @SpecAssertion(section="3.9.2")
    public void testInitializerMethodDeclaredInXml()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "webbeansxml"}) @SpecAssertion(section="3.8.2")
+   @Test(groups={"stub", "initializerMethod", "webbeansxml"}) 
+   @SpecAssertion(section="3.9.2")
    public void testInitializerMethodDeclaredInXmlIgnoresBindingAnnotationsInJava()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "webbeansxml"}, expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.8.2")
+   @Test(groups={"stub", "initializerMethod", "webbeansxml"}, expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.9.2")
    public void testInitializerMethodDeclaredInXmlDoesNotExist()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "initializerMethod", "webbeansxml"}) @SpecAssertion(section="3.8.2")
+   @Test(groups={"stub", "initializerMethod", "webbeansxml"}) 
+   @SpecAssertion(section="3.9.2")
    public void testBeanHasAllInitializerMethodsDeclaredInJavaAndXml()
    {
       assert false;

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/interceptor/InterceptorDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/interceptor/InterceptorDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/interceptor/InterceptorDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -3,6 +3,11 @@
 import org.jboss.webbeans.tck.impl.SpecAssertion;
 import org.testng.annotations.Test;
 
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class InterceptorDefinitionTest
 {
    

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/jms/JmsDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/jms/JmsDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/jms/JmsDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -6,6 +6,11 @@
 import org.jboss.webbeans.tck.impl.SpecAssertion;
 import org.testng.annotations.Test;
 
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class JmsDefinitionTest extends AbstractTest
 {
    

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -14,11 +14,14 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.literals.CurrentBinding;
 import org.testng.annotations.Test;
 
- at SpecVersion("PRD2")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class ProducerFieldDefinitionTest extends AbstractTest
 {
 

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldLifecycleTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldLifecycleTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/field/ProducerFieldLifecycleTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -11,10 +11,13 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
- at SpecVersion("PRD2")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class ProducerFieldLifecycleTest extends AbstractTest
 {
    /*

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/DisposalMethodDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/DisposalMethodDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/DisposalMethodDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -3,6 +3,11 @@
 import org.jboss.webbeans.tck.impl.SpecAssertion;
 import org.testng.annotations.Test;
 
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class DisposalMethodDefinitionTest
 {
    

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -10,14 +10,18 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081206")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class ProducerMethodDefinitionTest extends AbstractTest
 {
    
-   @Test(groups="producerMethod") @SpecAssertion(section="2.5.3")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="2.5.3")
    public void testProducerMethodInheritsDeploymentTypeOfDeclaringWebBean() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -27,7 +31,8 @@
       tarantulaModel.getDeploymentType().equals(AnotherDeploymentType.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4")
    public void testStaticMethod() throws Exception
    {
       Bean<BeanWithStaticProducerMethod> bean = createSimpleBean(BeanWithStaticProducerMethod.class);
@@ -36,13 +41,15 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test(groups={"stub", "producerMethod", "enterpriseBeans", "stub"}, expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.4")
+   @Test(groups={"stub", "producerMethod", "enterpriseBeans", "stub"}, expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.4")
    public void testProducerMethodIsNotBusinessMethod() throws Exception
    {
       assert false;
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4")
    public void testParameterizedReturnType() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -51,7 +58,8 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.4")
+   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.4")
    public void testParameterizedReturnTypeWithWildcard() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -60,7 +68,8 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.4")
+   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.4")
    public void testParameterizedReturnTypeWithTypeParameter() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -69,7 +78,8 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section={"3.4", "2.3.1"})
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section={"3.4", "2.3.1"})
    public void testDefaultBindingType() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -80,7 +90,8 @@
       assert tarantulaModel.getBindings().iterator().next().annotationType().equals(Current.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.1")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.1")
    public void testApiTypeForClassReturn() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -96,7 +107,8 @@
       assert tarantulaModel.getTypes().contains(Object.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.1")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.1")
    public void testApiTypeForInterfaceReturn() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -108,7 +120,8 @@
       assert animalModel.getTypes().contains(Object.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.1")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.1")
    public void testApiTypeForPrimitiveReturn() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -120,7 +133,8 @@
       assert intModel.getTypes().contains(Object.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section={"3.4.1", "2.2"})
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section={"3.4.1", "2.2"})
    public void testApiTypeForArrayTypeReturn() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -132,7 +146,8 @@
       assert spidersModel.getTypes().contains(Object.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.2")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.2")
    public void testBindingType() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -143,7 +158,8 @@
       assert tarantulaModel.getBindings().iterator().next().annotationType().equals(Tame.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.2")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.2")
    public void testScopeType() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -155,7 +171,8 @@
       // TODO Inherit scope from returned web bean?
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.2")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.2")
    public void testDeploymentType() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -165,7 +182,8 @@
       assert ladybirdSpiderModel.getDeploymentType().equals(Production.class);
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.2")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.2")
    public void testNamedMethod() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -175,7 +193,8 @@
       assert blackWidowSpiderModel.getName().equals("blackWidow");
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section="3.4.2")
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section="3.4.2")
    public void testDefaultNamedMethod() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -185,7 +204,8 @@
       assert daddyLongLegsSpiderModel.getName().equals("produceDaddyLongLegs");
    }
    
-   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.4")
+   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.4")
    public void testProducerMethodWithParameterAnnotatedDisposes() throws Exception
    {
       Bean<SpiderProducer_Broken> bean = createSimpleBean(SpiderProducer_Broken.class);
@@ -194,7 +214,8 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.4")
+   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.4")
    public void testProducerMethodWithParameterAnnotatedObserves() throws Exception
    {
       Bean<SpiderProducer_Broken> bean = createSimpleBean(SpiderProducer_Broken.class);
@@ -203,42 +224,48 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.3.5")
    public void testDisposalMethodNonStatic()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.3.5")
    public void testDisposalMethodMethodDeclaredOnWebBeanImplementationClass()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.3.5")
    public void testDisposalMethodBindingAnnotations()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.3.5")
    public void testDisposalMethodDefaultBindingAnnotations()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.3.5")
    public void testDisposalMethodDoesNotResolveToProducerMethod()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.5")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.4.6")
    public void testDisposalMethodDeclaredOnEnabledBean()
    {
       // TODO Placeholder
@@ -247,7 +274,8 @@
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.5")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.4.6")
    public void testBeanCanDeclareMultipleDisposalMethods()
    {
       // TODO move this 
@@ -255,7 +283,8 @@
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.3.5")
+   @Test(groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.4.6")
    public void testProducerMethodHasNoMoreThanOneDisposalMethod()
    {
       // TODO move this 
@@ -263,7 +292,8 @@
       assert false;
    }
    
-   @Test(groups="producerMethod") @SpecAssertion(section={"2.7.2", "3.4.2", "2.2"})
+   @Test(groups="producerMethod") 
+   @SpecAssertion(section={"2.7.2", "3.4.2", "2.2"})
    public void testStereotypeSpecifiesScope() throws Exception
    {
       Bean<SpiderProducer> bean = createSimpleBean(SpiderProducer.class);
@@ -275,7 +305,8 @@
       assert wolfSpider.getScopeType().equals(RequestScoped.class);
    }
    
-   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) @SpecAssertion(section={"2.7.2", "3.4.2", "2.2"})
+   @Test(groups="producerMethod", expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section={"2.7.2", "3.4.2", "2.2"})
    public void testStereotypeEnforcesTypes() throws Exception
    {
       Bean<SpiderProducer_Broken> bean = createSimpleBean(SpiderProducer_Broken.class);
@@ -284,7 +315,8 @@
       createProducerMethodBean(method, bean);
    }
    
-   @Test @SpecAssertion(section="4.2")
+   @Test 
+   @SpecAssertion(section="4.2")
    public void testNonStaticProducerMethodNotInherited()
    {
       deployBeans(InfertileChicken.class);

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodLifecycleTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodLifecycleTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/producer/method/ProducerMethodLifecycleTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -7,15 +7,18 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.util.MockCreationalContext;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081206")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class ProducerMethodLifecycleTest extends AbstractTest
 {
    
-   @Test(groups={"producerMethod", "broken"}) @SpecAssertion(section="5.6")
+   @Test(groups={"producerMethod", "broken"}) @SpecAssertion(section="B.1")
    public void testProducerMethodBeanCreate() throws Exception
    {
       Bean<SpiderProducer> spiderProducer = createSimpleBean(SpiderProducer.class); 
@@ -26,21 +29,21 @@
       assert tarantula != null;
    }
    
-   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.3")
+   @Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.3.4")
    public void testSpecializedBeanAlwaysUsed()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod", "beanLifecycle"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod", "beanLifecycle"}) @SpecAssertion(section="3.3.5")
    public void testDisposalMethodCalled()
    {
       // TODO Placeholder
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod", "beanLifecycle"}) @SpecAssertion(section="3.3.4")
+   @Test(groups={"stub", "disposalMethod", "beanLifecycle"}) @SpecAssertion(section="3.3.5")
    public void testDisposalMethodHasParametersInjected()
    {
       // TODO Placeholder
@@ -48,7 +51,8 @@
    }
    
    
-   @Test(groups={"producerMethod", "broken"}) @SpecAssertion(section={"3.4", "5.6", "8.3"})
+   @Test(groups={"producerMethod", "broken"}) 
+   @SpecAssertion(section={"3.4", "B.1", "7.3"})
    public void testProducerMethodReturnsNullIsDependent() throws Exception
    {
       Bean<SpiderProducer> spiderProducer = createSimpleBean(SpiderProducer.class); 
@@ -59,7 +63,8 @@
       assert spider == null;
    }
    
-   @Test(groups="producerMethod", expectedExceptions=IllegalProductException.class) @SpecAssertion(section={"3.4", "5.6"})
+   @Test(groups="producerMethod", expectedExceptions=IllegalProductException.class) 
+   @SpecAssertion(section={"3.4", "B.1"})
    public void testProducerMethodReturnsNullIsNotDependent() throws Exception
    {
       Bean<SpiderProducer_Broken> spiderProducer = createSimpleBean(SpiderProducer_Broken.class);

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/NewSimpleBeanTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/NewSimpleBeanTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/NewSimpleBeanTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -13,12 +13,15 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.literals.NewLiteral;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081222")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class NewSimpleBeanTest extends AbstractTest
 {
    
@@ -44,7 +47,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanIsDependentScoped()
    {
       assert Dependent.class.equals(newSimpleBean.getScopeType());
@@ -59,7 +62,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanIsOfStandardDeploymentType()
    {
       assert Standard.class.equals(newSimpleBean.getDeploymentType());
@@ -74,7 +77,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanIsHasOnlyNewBinding()
    {
       assert newSimpleBean.getBindings().size() == 1;
@@ -90,7 +93,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoWebBeanName()
    {
       assert newSimpleBean.getName() == null;
@@ -105,7 +108,7 @@
     *            declared type of the injection point.
     */
    @Test(groups = { "stub", "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoStereotypes()
    {
       assert false;
@@ -123,7 +126,7 @@
     * � has no decorators.
     */
    @Test(groups = {"new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoObservers()
    {
       assert false;
@@ -141,7 +144,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoProducerFields()
    {
       assert false;
@@ -159,7 +162,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new", "stub" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoProducerMethods()
    {
       assert false;
@@ -177,7 +180,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new" , "stub"})
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoDisposalMethods()
    {
       //Class<?> type = TypeInfo.ofTypes(newSimpleBean.getTypes()).getSuperClass();
@@ -197,7 +200,7 @@
     * � has no decorators.
     */
    @Test(groups = { "stub", "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasSameInterceptorMethodsAsWrappedBean()
    {
       assert false;
@@ -215,7 +218,7 @@
     * � has no decorators.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewBeanHasNoDecorators()
    {
       Annotation[] bindingTypes = newSimpleBean.getBindings().toArray(new Annotation[0]);
@@ -231,7 +234,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationMayBeAppliedToField()
    {
       deployBeans(AnnotatedField.class, WrappedSimpleBean.class);
@@ -247,7 +250,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationMayBeAppliedToProducerMethodParameter()
    {
       deployBeans(AnnotatedProducerParameter.class, WrappedSimpleBean.class);
@@ -263,7 +266,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationMayBeAppliedToInitializerMethodParameter()
    {
       deployBeans(AnnotatedInitializerParameter.class, WrappedSimpleBean.class);
@@ -279,7 +282,7 @@
     * Bean implementation class.
     */
    @Test(groups = { "new" })
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationMayBeAppliedToConstructorMethodParameter()
    {
       deployBeans(AnnotatedConstructorParameter.class, WrappedSimpleBean.class);
@@ -294,7 +297,7 @@
     * by the container at deployment time.
     */
    @Test(groups = { "new" }, expectedExceptions = DefinitionException.class)
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationCannotAppearInConjunctionWithOtherBindingType()
    {
       deployBeans(NewAndOtherBindingType_Broken.class);
@@ -308,7 +311,7 @@
     * by the container at deployment time.
     */
    @Test(groups = { "stub", "new" }, expectedExceptions = DefinitionException.class)
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationCannotBeAppliedToNonWebBeanImplementationClass()
    {
       assert false;
@@ -319,13 +322,14 @@
     * as a binding type
     */
    @Test(groups = { "stub", "new" }, expectedExceptions = DefinitionException.class)
-   @SpecAssertion(section = "3.9")
+   @SpecAssertion(section = "3.2.5")
    public void testNewAnnotationCannotBeExplicitlyDeclared()
    {
       assert false;
    }
    
-   @Test @SpecAssertion(section="3.2.5")
+   @Test 
+   @SpecAssertion(section="3.2.5")
    public void testForEachSimpleBeanANewBeanExists()
    {
       deployBeans(Order.class, Lion.class);

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanDefinitionTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanDefinitionTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanDefinitionTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -8,13 +8,16 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.util.MockCreationalContext;
 import org.jboss.webbeans.tck.unit.implementation.simple.OuterBean_Broken.InnerBean_Broken;
 import org.jboss.webbeans.tck.unit.implementation.simple.OuterBean_Broken.StaticInnerBean_Broken;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081206")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class SimpleBeanDefinitionTest extends AbstractTest
 {   
    
@@ -34,13 +37,15 @@
       createSimpleBean(Cow_Broken.class);
    }
    
-   @Test(groups="innerClass") @SpecAssertion(section="3.2")
+   @Test(groups="innerClass") 
+   @SpecAssertion(section="3.2")
    public void testStaticInnerClassDeclaredInJavaAllowed()
    {
       createSimpleBean(StaticInnerBean_Broken.class);
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups="innerClass") @SpecAssertion(section="3.2")
+   @Test(expectedExceptions=DefinitionException.class, groups="innerClass") 
+   @SpecAssertion(section="3.2")
    public void testNonStaticInnerClassDeclaredInJavaNotAllowed()
    {
       createSimpleBean(InnerBean_Broken.class);
@@ -53,7 +58,8 @@
       createSimpleBean(ParameterizedBean_Broken.class);
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "interceptors", "decorators"}) @SpecAssertion(section="3.2")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "interceptors", "decorators"}) 
+   @SpecAssertion(section="3.2")
    public void testClassCannotBeInterceptorAndDecorator()
    {
       
@@ -96,55 +102,64 @@
       
    }
    
-   @Test(groups={"stub", "producerMethod", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(groups={"stub", "producerMethod", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testBeanDeclaredInXmlIgnoresProducerMethodDeclaredInJava()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "disposalMethod", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(groups={"stub", "disposalMethod", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testBeanDeclaredInXmlIgnoresDisposalMethodDeclaredInJava()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "observerMethod", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(groups={"stub", "observerMethod", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testBeanDeclaredInXmlIgnoresObserverMethodDeclaredInJava()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testAbstractClassDeclaredInXmlIsNotAllowed()
    {
       
    }
    
-   @Test(groups={"stub", "innerClass", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(groups={"stub", "innerClass", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testStaticInnerClassDeclaredInXmlAllowed()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "innerClass", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "innerClass", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testNonStaticInnerClassDeclaredInXmlNotAllowed()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "webbeansxml"}) @SpecAssertion(section="3.2.4")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.4")
    public void testParameterizedClassDeclaredInXmlIsNotAllowed()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "interceptors"}) @SpecAssertion(section="3.2.4")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "interceptors"}) 
+   @SpecAssertion(section="3.2.4")
    public void testClassHasInterceptorInJavaMustHaveInterceptorInXml()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "interceptors"}) @SpecAssertion(section="3.2.4")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "interceptors"}) 
+   @SpecAssertion(section="3.2.4")
    public void testClassHasDecoratorInJavaMustHaveDecoratorInXml()
    {
       assert false;
@@ -167,21 +182,24 @@
       
    }
    
-   @Test @SpecAssertion(section="3.2.5.1")
+   @Test 
+   @SpecAssertion(section="3.2.5.1")
    public void testImplicitConstructorUsed()
    {
       Bean<Order> order = createSimpleBean(Order.class);
       // TODO Test this properly!
    }
    
-   @Test @SpecAssertion(section="3.2.5.1")
+   @Test 
+   @SpecAssertion(section="3.2.6.1")
    public void testEmptyConstructorUsed()
    {
       createSimpleBean(Donkey.class).create(new MockCreationalContext<Donkey>());
       assert Donkey.constructedCorrectly;
    }
    
-   @Test @SpecAssertion(section="3.2.5.1")
+   @Test 
+   @SpecAssertion(section="3.2.6.1")
    public void testInitializerAnnotatedConstructorUsedOverEmptyConstuctor() throws Exception
    {
       deployBeans(Turkey.class);
@@ -196,49 +214,57 @@
       }.run();
    }
    
-   @Test(expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.2.5.1")
+   @Test(expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.2.6.1")
    public void testTooManyInitializerAnnotatedConstructor()
    {
       createSimpleBean(Goose_Broken.class);
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "disposalMethod"}) @SpecAssertion(section="3.2.5.1")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "disposalMethod"}) 
+   @SpecAssertion(section="3.2.6.1")
    public void testConstructorHasDisposesParameter()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "observerMethod"}) @SpecAssertion(section="3.2.5.1")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "observerMethod"}) 
+   @SpecAssertion(section="3.2.6.1")
    public void testConstructorHasObservesParameter()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "webbeansxml"}) @SpecAssertion(section="3.2.5.2")
+   @Test(groups={"stub", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.6.2")
    public void testImplicitConstructorDeclaredInXmlUsed()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "webbeansxml"})  @SpecAssertion(section="3.2.5.2")
+   @Test(groups={"stub", "webbeansxml"})  
+   @SpecAssertion(section="3.2.6.2")
    public void testEmptyConstructorDeclaredInXmlUsed()
    {
       assert false;
    }
    
-   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "webbeansxml"}) @SpecAssertion(section="3.2.5.2")
+   @Test(expectedExceptions=DefinitionException.class, groups={"stub", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.6.2")
    public void testConstructorDeclaredInXmlDoesNotExist()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "webbeansxml"}) @SpecAssertion(section="3.2.5.2")
+   @Test(groups={"stub", "webbeansxml"}) 
+   @SpecAssertion(section="3.2.6.2")
    public void testConstructorDeclaredInXmlIgnoresBindingTypesDeclaredInJava()
    {
       assert false;
    }
    
-   @Test @SpecAssertion(section="3.2.5.3")
+   @Test 
+   @SpecAssertion(section="3.2.6.3")
    public void testBindingTypeAnnotatedConstructor() throws Exception
    {
       deployBeans(Duck.class);
@@ -253,7 +279,8 @@
       }.run();
    }
    
-   @Test @SpecAssertion(section="3.2")
+   @Test 
+   @SpecAssertion(section="3.2")
    public void testDependentScopedBeanCanHavePublicField() throws Exception
    {
       deployBeans(Tiger.class);
@@ -270,7 +297,8 @@
       
    }
    
-   @Test(expectedExceptions=DefinitionException.class) @SpecAssertion(section="3.2")
+   @Test(expectedExceptions=DefinitionException.class) 
+   @SpecAssertion(section="3.2")
    public void testNonDependentScopedBeanCanNotHavePublicField()
    {
       deployBeans(Leopard_Broken.class);

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanLifecycleTest.java
===================================================================
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanLifecycleTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/simple/SimpleBeanLifecycleTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -7,11 +7,14 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.jboss.webbeans.tck.impl.util.MockCreationalContext;
 import org.testng.annotations.Test;
 
- at SpecVersion("20081206")
+/**
+ * 
+ * Spec version: PRD2
+ *
+ */
 public class SimpleBeanLifecycleTest extends AbstractTest
 {
    
@@ -23,7 +26,8 @@
       return deploymentTypes;
    }
 	
-	@Test(groups="beanConstruction") @SpecAssertion(section="3.1.3")
+	@Test(groups="beanConstruction") 
+	@SpecAssertion(section="3.2.5.3")
 	public void testInjectionOfParametersIntoBeanConstructor()
 	{
 	   Bean<FishPond> goldfishPondBean = createSimpleBean(FishPond.class);
@@ -34,7 +38,7 @@
 	   assert fishPond.goldfish != null;
 	}
 	
-	@Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.1.4")
+	@Test(groups={"stub", "specialization"}) @SpecAssertion(section="3.2.6")
    public void testSpecializedBeanAlwaysUsed()
    {
       // TODO Placeholder
@@ -48,37 +52,43 @@
       assert bean.create(new MockCreationalContext<RedSnapper>()) instanceof RedSnapper;
    }
    
-   @Test(groups={"stub", "beanLifecycle", "interceptors"}) @SpecAssertion(section="5.3")
+   @Test(groups={"stub", "beanLifecycle", "interceptors"}) 
+   @SpecAssertion(section="6.3")
    public void testCreateBindsInterceptorStack()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "beanLifecycle", "decorators"}) @SpecAssertion(section="5.3")
+   @Test(groups={"stub", "beanLifecycle", "decorators"}) 
+   @SpecAssertion(section="6.3")
    public void testCreateBindsDecoratorStack()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "beanLifecycle", "commonAnnotations"}) @SpecAssertion(section="5.3")
+   @Test(groups={"stub", "beanLifecycle", "commonAnnotations"}) 
+   @SpecAssertion(section="6.3")
    public void testCreateInjectsEjb()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "beanLifecycle", "commonAnnotations"}) @SpecAssertion(section="5.3")
+   @Test(groups={"stub", "beanLifecycle", "commonAnnotations"}) 
+   @SpecAssertion(section="6.3")
    public void testCreateInjectsPersistenceContext()
    {
       assert false;
    }
    
-   @Test(groups={"stub", "beanLifecycle", "commonAnnotations"}) @SpecAssertion(section="5.3")
+   @Test(groups={"stub", "beanLifecycle", "commonAnnotations"}) 
+   @SpecAssertion(section="6.3")
    public void testCreateInjectsResource()
    {
       assert false;
    }
    
-   @Test(groups={"beanLifecycle", "lifecycleCallbacks"}) @SpecAssertion(section="5.3")
+   @Test(groups={"beanLifecycle", "lifecycleCallbacks"}) 
+   @SpecAssertion(section="6.3")
    public void testPostConstructPreDestroy() throws Exception
    {
       Bean<FarmOffice> farmOfficeBean = createSimpleBean(FarmOffice.class);
@@ -161,7 +171,7 @@
 
    }
    
-   @Test(groups="injection") @SpecAssertion(section="5.3")
+   @Test(groups="injection") @SpecAssertion(section="6.3")
    public void testCreateInjectsFieldsDeclaredInJava()
    {
       Bean<TunaFarm> tunaFarmBean = createSimpleBean(TunaFarm.class);




More information about the weld-commits mailing list
--- tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanLifecycleTest.java	2009-01-28 01:05:25 UTC (rev 1257)
+++ tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanLifecycleTest.java	2009-01-28 08:29:38 UTC (rev 1258)
@@ -6,22 +6,21 @@
 
 import org.jboss.webbeans.tck.AbstractTest;
 import org.jboss.webbeans.tck.impl.SpecAssertion;
-import org.jboss.webbeans.tck.impl.SpecVersion;
 import org.testng.annotations.Test;
 
 /**
  * Sections
  * 
  * 6.4. Lifecycle of stateful session enterprise Web beans
  * 6.5. Lifecycle of stateless session and singleton enterprise Web Beans
  * 6.9. Lifecycle of EJB beans
  * 
  * Mostly overlapping with other tests...
  * 
- * @author Nicklas Karlsson 
+ * @author Nicklas Karlsson
+ * 
+ *  Spec version: PRD2
  */
-
- at SpecVersion("20081206")
 public class EnterpriseBeanLifecycleTest extends AbstractTest
 {
    
@@ -30,7 +29,7 @@
     * returns an enterprise bean proxy
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "stub" })
-   @SpecAssertion(section = "6.4")
+   @SpecAssertion(section = "6.5")
    public void testProxyCreated()
    {
       assert false;
@@ -41,7 +40,7 @@
     * Bean remove method upon the proxy
     */
    @Test(groups = { "enterpriseBeans", "clientProxy", "lifecycle", "stub"})
-   @SpecAssertion(section = "6.4")
+   @SpecAssertion(section = "6.5")
    public void testRemoveMethodCalled() throws Exception
    {
       GoodDoggie.destructorCalled = false;
@@ -67,7 +66,7 @@
     * returned by Manager.getInstanceByType()
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "removeMethod", "stub" })
-   @SpecAssertion(section = "6.4")
+   @SpecAssertion(section = "6.5")
    public void testFieldInjections()
    {
       assert false;
@@ -79,7 +78,7 @@
     * instance, and is not required to call any remove method
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "removeMethod", "stub" })
-   @SpecAssertion(section = "6.4")
+   @SpecAssertion(section = "6.5")
    public void testNoRemoveMethodsCalledIfEnterpriseBeanAlreadyRemoved()
    {
       assert false;
@@ -90,7 +89,7 @@
     * the proxy and all EJB local object references.
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "removeMethod", "stub" })
-   @SpecAssertion(section = "6.5")
+   @SpecAssertion(section = "6.6")
    public void testProxyAndLocalObjectReferencesDiscardedForStatelessEnterpriseBeans()
    {
       assert false;
@@ -102,7 +101,7 @@
     * returned by Manager.getInstanceByType().
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "stub" })
-   @SpecAssertion(section = "6.9")
+   @SpecAssertion(section = "6.11")
    public void testFieldInjectionsOnRemoveMethods()
    {
       assert false;
@@ -114,7 +113,7 @@
     * in XML,
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "stub" })
-   @SpecAssertion(section = "6.9")
+   @SpecAssertion(section = "6.11")
    public void testInitXMLDefinedValuesOnWebWeanEnterpriseBeans()
    {
       assert false;
@@ -126,7 +125,7 @@
     * returned by Manager.getInstanceByType().
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "stub" })
-   @SpecAssertion(section = "6.9")
+   @SpecAssertion(section = "6.11")
    public void testInitializerMethodsCalledWithCurrentParameterValues()
    {
       assert false;
@@ -137,7 +136,7 @@
     * for the instance
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "interceptors", "stub" })
-   @SpecAssertion(section = "6.9")
+   @SpecAssertion(section = "6.11")
    public void testInterceptorStackIsBuilt()
    {
       assert false;
@@ -148,7 +147,7 @@
     * for the instance
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "decorators", "stub" })
-   @SpecAssertion(section = "6.9")
+   @SpecAssertion(section = "6.11")
    public void testDecoratorStackIsBuilt()
    {
       assert false;
@@ -160,7 +159,7 @@
     * objects, after the callback returns from the bean instance
     */
    @Test(groups = { "enterpriseBeans", "lifecycle", "stub" })
-   @SpecAssertion(section = "6.9")
+   @SpecAssertion(section = "6.11")
    public void testDependentObjectsDestroyed()
    {
       assert false;
@@ -6,22 +6,21 @@
  * Sections
  * 
- * 6.4. Lifecycle of stateful session enterprise Web beans
- * 6.5. Lifecycle of stateless session and singleton enterprise Web Beans
- * 6.9. Lifecycle of EJB beans
+ * 6.5. Lifecycle of stateful session beans
+ * 6.6. Lifecycle of stateless session and singleton beans
+ * 6.11. Lifecycle of EJBs
  * 
  * Mostly overlapping with other tests...

Modified: tck/trunk/impl/src/main/java/org/jboss/webbeans/tck/unit/implementation/enterprise/EnterpriseBeanRemoveMethodTest.java
===================================================================